Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'extraplugins/eastadl/org.eclipse.papyrus.eastadl/src/org/eclipse/papyrus/eastadl/timing/events/EventFunctionClientServerPort.java')
-rw-r--r--extraplugins/eastadl/org.eclipse.papyrus.eastadl/src/org/eclipse/papyrus/eastadl/timing/events/EventFunctionClientServerPort.java83
1 files changed, 28 insertions, 55 deletions
diff --git a/extraplugins/eastadl/org.eclipse.papyrus.eastadl/src/org/eclipse/papyrus/eastadl/timing/events/EventFunctionClientServerPort.java b/extraplugins/eastadl/org.eclipse.papyrus.eastadl/src/org/eclipse/papyrus/eastadl/timing/events/EventFunctionClientServerPort.java
index a0dde822f40..45774695193 100644
--- a/extraplugins/eastadl/org.eclipse.papyrus.eastadl/src/org/eclipse/papyrus/eastadl/timing/events/EventFunctionClientServerPort.java
+++ b/extraplugins/eastadl/org.eclipse.papyrus.eastadl/src/org/eclipse/papyrus/eastadl/timing/events/EventFunctionClientServerPort.java
@@ -15,9 +15,8 @@
*****************************************************************************/
package org.eclipse.papyrus.eastadl.timing.events;
-import org.eclipse.emf.common.util.EList;
-import org.eclipse.papyrus.eastadl.structure.functionmodeling.FunctionClientServerPort;
-import org.eclipse.papyrus.eastadl.structure.functionmodeling.FunctionPrototype;
+import org.eclipse.papyrus.eastadl.infrastructure.EventFunctionClientServerPortInstanceRef;
+import org.eclipse.papyrus.eastadl.infrastructure.values.EAExpression;
import org.eclipse.papyrus.eastadl.timing.Event;
@@ -25,43 +24,38 @@ import org.eclipse.papyrus.eastadl.timing.Event;
* <!-- begin-user-doc -->
* A representation of the model object '<em><b>Event Function Client Server Port</b></em>'.
* <!-- end-user-doc -->
- *
+ *
* <!-- begin-model-doc -->
- * Event that refers to the triggering of the Function at a client/server port, i.e., when the input data is sent / received, or when the output data
- * is produced / received.
+ * Event that refers to the triggering of the Function at a client/server port, i.e., when the input data is sent / received, or when the output data is produced / received.
*
* Constraints:
- * [1] eventKind is sentRequest or receivedResponse for a FunctionClientServerPort of type client. Rationale: Only these values make sense for client
- * ports.
+ * [1] eventKind is sentRequest or receivedResponse for a FunctionClientServerPort of type client. Rationale: Only these values make sense for client ports.
*
- * [2] eventKind is receivedRequest or sentResponse for a FunctionClientServerPort of type server. Rationale: Only these values make sense for server
- * ports.
+ * [2] eventKind is receivedRequest or sentResponse for a FunctionClientServerPort of type server. Rationale: Only these values make sense for server ports.
* <!-- end-model-doc -->
- *
+ *
* <p>
* The following features are supported:
* <ul>
- * <li>{@link org.eclipse.papyrus.eastadl.timing.events.EventFunctionClientServerPort#getEventKind <em>Event Kind</em>}</li>
- * <li>{@link org.eclipse.papyrus.eastadl.timing.events.EventFunctionClientServerPort#getPort <em>Port</em>}</li>
- * <li>{@link org.eclipse.papyrus.eastadl.timing.events.EventFunctionClientServerPort#getPort_path <em>Port path</em>}</li>
+ * <li>{@link org.eclipse.papyrus.eastadl.timing.events.EventFunctionClientServerPort#getEventKind <em>Event Kind</em>}</li>
+ * <li>{@link org.eclipse.papyrus.eastadl.timing.events.EventFunctionClientServerPort#getPort <em>Port</em>}</li>
* </ul>
* </p>
- *
+ *
* @see org.eclipse.papyrus.eastadl.timing.events.EventsPackage#getEventFunctionClientServerPort()
* @model
* @generated
*/
-public interface EventFunctionClientServerPort extends Event {
-
+public interface EventFunctionClientServerPort extends Event, EAExpression {
/**
* Returns the value of the '<em><b>Event Kind</b></em>' attribute.
* The literals are from the enumeration {@link org.eclipse.papyrus.eastadl.timing.events.EventFunctionClientServerPortKind}.
* <!-- begin-user-doc -->
* <p>
- * If the meaning of the '<em>Event Kind</em>' attribute isn't clear, there really should be more of a description here...
+ * If the meaning of the '<em>Event Kind</em>' attribute isn't clear,
+ * there really should be more of a description here...
* </p>
* <!-- end-user-doc -->
- *
* @return the value of the '<em>Event Kind</em>' attribute.
* @see org.eclipse.papyrus.eastadl.timing.events.EventFunctionClientServerPortKind
* @see #setEventKind(EventFunctionClientServerPortKind)
@@ -72,61 +66,40 @@ public interface EventFunctionClientServerPort extends Event {
EventFunctionClientServerPortKind getEventKind();
/**
- * Returns the value of the '<em><b>Port</b></em>' reference.
+ * Returns the value of the '<em><b>Port</b></em>' containment reference.
* <!-- begin-user-doc -->
* <p>
- * If the meaning of the '<em>Port</em>' containment reference isn't clear, there really should be more of a description here...
+ * If the meaning of the '<em>Port</em>' containment reference isn't clear,
+ * there really should be more of a description here...
* </p>
* <!-- end-user-doc -->
*
* @return the value of the '<em>Port</em>' reference.
* @see #setPort(FunctionClientServerPort)
* @see org.eclipse.papyrus.eastadl.timing.events.EventsPackage#getEventFunctionClientServerPort_Port()
- * @model required="true" ordered="false"
+ * @model containment="true" required="true" ordered="false"
* @generated
*/
- FunctionClientServerPort getPort();
+ EventFunctionClientServerPortInstanceRef getPort();
/**
- * Sets the value of the '{@link org.eclipse.papyrus.eastadl.timing.events.EventFunctionClientServerPort#getEventKind <em>Event Kind</em>}'
- * attribute.
+ * Sets the value of the '{@link org.eclipse.papyrus.eastadl.timing.events.EventFunctionClientServerPort#getPort <em>Port</em>}' containment reference.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- *
- * @param value
- * the new value of the '<em>Event Kind</em>' attribute.
- * @see org.eclipse.papyrus.eastadl.timing.events.EventFunctionClientServerPortKind
- * @see #getEventKind()
- * @generated
- */
- void setEventKind(EventFunctionClientServerPortKind value);
-
- /**
- * Sets the value of the '{@link org.eclipse.papyrus.eastadl.timing.events.EventFunctionClientServerPort#getPort <em>Port</em>}' reference.
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
- *
- * @param value
- * the new value of the '<em>Port</em>' reference.
+ * @param value the new value of the '<em>Port</em>' containment reference.
* @see #getPort()
* @generated
*/
- void setPort(FunctionClientServerPort value);
+ void setPort(EventFunctionClientServerPortInstanceRef value);
/**
- * Returns the value of the '<em><b>Port path</b></em>' reference list.
- * The list contents are of type {@link org.eclipse.papyrus.eastadl.structure.functionmodeling.FunctionPrototype}.
+ * Sets the value of the '{@link org.eclipse.papyrus.eastadl.timing.events.EventFunctionClientServerPort#getEventKind <em>Event Kind</em>}' attribute.
* <!-- begin-user-doc -->
- * <p>
- * If the meaning of the '<em>Port path</em>' reference list isn't clear, there really should be more of a description here...
- * </p>
* <!-- end-user-doc -->
- *
- * @return the value of the '<em>Port path</em>' reference list.
- * @see org.eclipse.papyrus.eastadl.timing.events.EventsPackage#getEventFunctionClientServerPort_Port_path()
- * @model
+ * @param value the new value of the '<em>Event Kind</em>' attribute.
+ * @see org.eclipse.papyrus.eastadl.timing.events.EventFunctionClientServerPortKind
+ * @see #getEventKind()
* @generated
*/
- EList<FunctionPrototype> getPort_path();
+ void setEventKind(EventFunctionClientServerPortKind value);
} // EventFunctionClientServerPort

Back to the top
@@ -72,61 +66,40 @@ public interface EventFunctionClientServerPort extends Event {
* </p>
* <!-- end-user-doc -->
- *
- * @return the value of the '<em>Port</em>' reference.
- * @see #setPort(FunctionClientServerPort)
+ * @return the value of the '<em>Port</em>' containment reference.
+ * @see #setPort(EventFunctionClientServerPortInstanceRef)
* @see org.eclipse.papyrus.eastadl.timing.events.EventsPackage#getEventFunctionClientServerPort_Port()